/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 Open-Xchange GmbH.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ant.tasks;

import java.util.Arrays;
import java.util.HashSet;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;

/**
 * Will return a String  propertyName
 *
 * @author <a href="mailto:felix.marx@open-xchange.com">Felix Marx</a>
 */
public class MinusProperty extends Task {

    private HashSet<String> current;
    private HashSet<String> minus;
    private String property;
    private String delimiter;

    public MinusProperty() {
        super();
    }

    public final void setProperty(final String property) {
        this.property = property;
    }

    public void setCurrent(final String current){
        if (current.length() != 0){
            this.current = new HashSet<String>(Arrays.asList(current.split(",", 0)));
        }
    }

    public void setMinus(final String minus){
        if (minus.length() != 0){
            this.minus = new HashSet<String>(Arrays.asList(minus.split(",", 0)));
        }
    }

    public void setDelimiter(final String delimiter){
        if (delimiter.length() != 0){
            this.delimiter = delimiter;
        }
    }

    @Override
    public final void execute() throws BuildException {
        if (property == null) {
            throw new BuildException("Please define property.");
        }

        if (delimiter == null) {
            log("No delimiter is set, will use \",\"", Project.MSG_ERR);
            delimiter = ",";
        }

        if(minus == null || current == null) {
            throw new BuildException("Please define both, current and minus.");
        }

        HashSet<String> tmp = new HashSet<String>();
        for (String s:current){
            if (!minus.contains(s)) {
                tmp.add(s);
            }
        }
        StringBuilder sb = new StringBuilder();
        for (String s : tmp) {
            sb.append(s);
            sb.append(delimiter);
        }
        getProject().setInheritedProperty(property , sb.toString());
    }
}
